(* Content-type: application/vnd.wolfram.cdf.text *)

(*** Wolfram CDF File ***)
(* http://www.wolfram.com/cdf *)

(* CreatedBy='Mathematica 11.0' *)

(*************************************************************************)
(*                                                                       *)
(*  The Mathematica License under which this file was created prohibits  *)
(*  restricting third parties in receipt of this file from republishing  *)
(*  or redistributing it by any means, including but not limited to      *)
(*  rights management or terms of use, without the express consent of    *)
(*  Wolfram Research, Inc. For additional information concerning CDF     *)
(*  licensing and redistribution see:                                    *)
(*                                                                       *)
(*        www.wolfram.com/cdf/adopting-cdf/licensing-options.html        *)
(*                                                                       *)
(*************************************************************************)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[      1064,         20]
NotebookDataLength[     38586,        834]
NotebookOptionsPosition[     39015,        825]
NotebookOutlinePosition[     39480,        845]
CellTagsIndexPosition[     39437,        842]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Stress on Oblique plane\n",
 StyleBox["Zhelong He, Marek-Jerzy Pindera \nUniversity of Virginia, \
2018-01-18",
  FontSize->16,
  FontColor->GrayLevel[0]]
}], "Title",
 TextAlignment->Center],

Cell[TextData[{
 "This module is designed to show the stresses on an oblique plane with \
inclined angle \[Theta] under axial loading.\nConsider a rectangular bar with \
constant cross section shown below, which is subjected to the axial force P. \
Now, consider an oblique plane that passes through the bar and is inclined at \
the angle \[Theta] relative to the vertical axis. What will be the forces and \
stresses acting on this oblique plane? We will follow the following three \
steps in addressing this question. \nStep 1: Using the method of sections we \
determine that the force acting on the inclined plane should be P to ensure \
horizontal equilibrium. \nStep 2: We resolve P into two components, normal \
force N which is perpendicular to the inclined plane and shear force V which \
is parallel to the inclined plane. \nStep 3: We use the definition of the \
normal and shear stress, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Sigma]", " ", "=", " ", 
    FractionBox["N", 
     SubscriptBox["A", "\[Theta]"]]}], TraditionalForm]]],
 " and  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Tau]", " ", "=", " ", 
    FractionBox["V", 
     SubscriptBox["A", "\[Theta]"]]}], TraditionalForm]]],
 ", to calculate these stresses noting that the area of the inclined plane is \
related to the area perpendicular to the x-axis by ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["A", "\[Theta]"], " ", "=", " ", 
    RowBox[{
     FractionBox[
      SubscriptBox["A", "0"], "Cos\[Theta]"], "."}]}], TraditionalForm]]]
}], "Text",
 TextAlignment->AlignmentMarker],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`an$$ = 45, $CellContext`h$$ = 
    2, $CellContext`num1$$ = 0, $CellContext`num2$$ = 0, $CellContext`opa2$$ =
     0, $CellContext`opa3$$ = 0, $CellContext`opa4$$ = 0, $CellContext`p$$ = 
    5, $CellContext`plot1$$ = 0, $CellContext`plot2$$ = 0, Typeset`show$$ = 
    True, Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`p$$], 5, ""}, -10, 10, 0.1}, {{
       Hold[$CellContext`an$$], 45, ""}, -75, 75, 0.1}, {{
       Hold[$CellContext`h$$], 2, ""}, 1, 2.5, 0.1}, {{
       Hold[$CellContext`opa2$$], 0, 
       Row[{
         Text[
          Style["Equilibrium", Bold]], 
         Spacer[28]}]}, {1 -> "On", 0 -> "Off"}}, {{
       Hold[$CellContext`opa3$$], 0, 
       Row[{
         Text[
          Style["Resolution", Bold]], 
         Spacer[30]}]}, {1 -> "On", 0 -> "Off"}}, {{
       Hold[$CellContext`plot1$$], 0, 
       Row[{
         Text[
          Style["Forces plot", Bold]], 
         Spacer[27]}]}, {1 -> "On", 0 -> "Off"}}, {{
       Hold[$CellContext`num1$$], 0, 
       Row[{
         Text[
          Style["Numeric Value", Bold]], 
         Spacer[11]}]}, {1 -> "On", 0 -> "Off"}}, {{
       Hold[$CellContext`opa4$$], 0, 
       Text[
        Style["Internal stresses", Bold]]}, {1 -> "On", 0 -> "Off"}}, {{
       Hold[$CellContext`plot2$$], 0, 
       Row[{
         Text[
          Style["Stresses plot", Bold]], 
         Spacer[18]}]}, {1 -> "On", 0 -> "Off"}}, {{
       Hold[$CellContext`num2$$], 0, 
       Row[{
         Text[
          Style["Numeric Value", Bold]], 
         Spacer[11]}]}, {1 -> "On", 0 -> "Off"}}, {
      Hold[
       Grid[{{
          Grid[{{
             Text[
              Style["Parameters Setting", Bold]], SpanFromLeft}, {"P", 
             Manipulate`Place[1]}, {"\[Theta]", 
             Manipulate`Place[2]}, {"H", 
             Manipulate`Place[3]}, {
             Text[
              Style["Unit Width, W = 1"]], SpanFromLeft}}, Spacings -> {0, 1},
            Alignment -> Left, Frame -> None]}, {
          Grid[{{
             Manipulate`Place[4]}}, Alignment -> Left, Frame -> None]}, {
          Grid[{{
             Manipulate`Place[5]}, {
             PaneSelector[{1 -> Manipulate`Place[6]}, 
              Dynamic[
               Boole[$CellContext`opa3$$ == 1]]]}, {
             PaneSelector[{1 -> Manipulate`Place[7]}, 
              Dynamic[
               Boole[
                And[$CellContext`opa3$$ == 1, $CellContext`plot1$$ == 1]]]]}},
            Alignment -> Left, Frame -> None]}, {
          Grid[{{
             Manipulate`Place[8]}, {
             PaneSelector[{1 -> Manipulate`Place[9]}, 
              Dynamic[
               Boole[$CellContext`opa4$$ == 1]]]}, {
             PaneSelector[{1 -> Manipulate`Place[10]}, 
              Dynamic[
               Boole[
                And[$CellContext`opa4$$ == 1, $CellContext`plot2$$ == 1]]]]}},
            Alignment -> Left, Frame -> None]}}, 
        Spacings -> {0, {1, 3.7, 6.5, 3.5}}, Alignment -> Left]], 
      Manipulate`Dump`ThisIsNotAControl}}, Typeset`size$$ = {
    468., {331.5, 340.5}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`p$186780$$ = 
    0, $CellContext`an$186781$$ = 0, $CellContext`h$186782$$ = 
    0, $CellContext`opa2$186783$$ = False, $CellContext`opa3$186784$$ = 
    False, $CellContext`plot1$186785$$ = False, $CellContext`num1$186786$$ = 
    False, $CellContext`opa4$186787$$ = False, $CellContext`plot2$186788$$ = 
    False, $CellContext`num2$186789$$ = False}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`an$$ = 45, $CellContext`h$$ = 
        2, $CellContext`num1$$ = 0, $CellContext`num2$$ = 
        0, $CellContext`opa2$$ = 0, $CellContext`opa3$$ = 
        0, $CellContext`opa4$$ = 0, $CellContext`p$$ = 
        5, $CellContext`plot1$$ = 0, $CellContext`plot2$$ = 0}, 
      "ControllerVariables" :> {
        Hold[$CellContext`p$$, $CellContext`p$186780$$, 0], 
        Hold[$CellContext`an$$, $CellContext`an$186781$$, 0], 
        Hold[$CellContext`h$$, $CellContext`h$186782$$, 0], 
        Hold[$CellContext`opa2$$, $CellContext`opa2$186783$$, False], 
        Hold[$CellContext`opa3$$, $CellContext`opa3$186784$$, False], 
        Hold[$CellContext`plot1$$, $CellContext`plot1$186785$$, False], 
        Hold[$CellContext`num1$$, $CellContext`num1$186786$$, False], 
        Hold[$CellContext`opa4$$, $CellContext`opa4$186787$$, False], 
        Hold[$CellContext`plot2$$, $CellContext`plot2$186788$$, False], 
        Hold[$CellContext`num2$$, $CellContext`num2$186789$$, False]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`\[Theta]$, $CellContext`\[Sigma]$, $CellContext`\
\[Tau]$}, $CellContext`l = 10; $CellContext`w = 1; $CellContext`pw = 
         2 ($CellContext`p$$/5); $CellContext`h0 = 
         2; $CellContext`area = $CellContext`w $CellContext`h$$; \
$CellContext`\[Beta] = 75; $CellContext`opa0 = 
         0; $CellContext`\[Theta]$ = $CellContext`an$$ (Pi/
           180); $CellContext`f = $CellContext`p$$ 
          Cos[$CellContext`\[Theta]$]; $CellContext`v = $CellContext`p$$ 
          Sin[$CellContext`\[Theta]$]; $CellContext`fw = 
         2 ($CellContext`f/5); $CellContext`vw = 
         2 ($CellContext`v/5); $CellContext`ns = 
         Cos[$CellContext`\[Theta]$] ($CellContext`f/$CellContext`area); \
$CellContext`ss = 
         Cos[$CellContext`\[Theta]$] ($CellContext`v/$CellContext`area); \
$CellContext`nsw = $CellContext`ns + (4 Normalize[$CellContext`ns]) 
           Abs[Cos[$CellContext`\[Beta] 
                Degree]^2 ($CellContext`p$$/$CellContext`area)]; \
$CellContext`ssw = 
         0.5 $CellContext`ss + (0.5 Normalize[$CellContext`ss]) 
           Abs[(Cos[$CellContext`\[Beta] Degree] 
              Sin[$CellContext`\[Beta] 
                Degree]) ($CellContext`p$$/$CellContext`area)]; \
$CellContext`nq = 
         Table[$CellContext`i, {$CellContext`i, 
            0, $CellContext`h$$, $CellContext`h$$/12}]; $CellContext`sq = 
         If[$CellContext`\[Theta]$ >= 0, 
           
           Table[$CellContext`i, {$CellContext`i, 
             0, (5/6) $CellContext`h$$, $CellContext`h$$/3}], 
           
           Table[$CellContext`i, {$CellContext`i, (1/
              6) $CellContext`h$$, (5/6) $CellContext`h$$ + (1/
               6) $CellContext`h$$, $CellContext`h$$/3}]]; $CellContext`nq2 = 
         Table[$CellContext`i, {$CellContext`i, 
            0, $CellContext`l, $CellContext`l/12}]; $CellContext`sq2 = 
         If[$CellContext`\[Theta]$ >= 0, 
           
           Table[$CellContext`i, {$CellContext`i, 
             0, (5/6) $CellContext`l, $CellContext`l/3}], 
           
           Table[$CellContext`i, {$CellContext`i, (1/
              6) $CellContext`l, (5/6) $CellContext`l + (1/
               6) $CellContext`l, $CellContext`l/3}]]; $CellContext`rgxp = 
         1.5 $CellContext`l; $CellContext`rgxn = (-0.5) $CellContext`l; \
$CellContext`rgyp = 
         2.3 $CellContext`h0; $CellContext`rgyn = (-1.3) $CellContext`h0; \
$CellContext`imz = 300; $CellContext`pts = 0.05; $CellContext`color = 
         Gray; $CellContext`tx = 75; $CellContext`ty = 1; Grid[{{
            Graphics[{LightBlue, 
              Rectangle[{0, 0}, {$CellContext`l, $CellContext`h$$}], Black, 
              Thickness[0.005], 
              
              Arrow[{{$CellContext`l, $CellContext`h$$/
                 2}, {$CellContext`l + $CellContext`pw, $CellContext`h$$/2}}], 
              
              Arrow[{{0, $CellContext`h$$/
                 2}, {-$CellContext`pw, $CellContext`h$$/2}}], 
              Darker[Red], 
              Rotate[
               
               Line[{{$CellContext`l/
                  2, (-1.5) $CellContext`h$$}, {$CellContext`l/2, 
                  
                  2.5 $CellContext`h$$}}], $CellContext`\[Theta]$, \
{$CellContext`l/2, $CellContext`h$$/2}], Black, 
              Text["P", {(-$CellContext`pw)/2, $CellContext`h$$}], 
              Text[
              "P", {$CellContext`l + $CellContext`pw/2, $CellContext`h$$}], 
              If[
               
               And[$CellContext`\[Theta]$ != 0, $CellContext`\[Theta]$ != 
                Pi], {Dashed, 
                Thickness[0.002], 
                
                Line[{{$CellContext`l/
                   2, (-0.5) $CellContext`h$$}, {$CellContext`l/2, 
                   1.5 $CellContext`h$$}}], 
                
                Circle[{$CellContext`l/2, 0.5 $CellContext`h$$}, 
                 0.8 $CellContext`h$$, {Pi/2, Pi/2 + $CellContext`\[Theta]$}], 
                Text[
                 Style[
                 "\[Theta]"], {$CellContext`l/2, 0.5 $CellContext`h$$} + (
                   1 $CellContext`h$$) {
                    Cos[Pi/2 + $CellContext`\[Theta]$/2], 
                    Sin[Pi/2 + $CellContext`\[Theta]$/2]}]}]}, 
             PlotRange -> {{$CellContext`rgxn, $CellContext`rgxp}, \
{$CellContext`rgyn, $CellContext`rgyp}}, ImageSize -> $CellContext`imz], 
            If[
             And[$CellContext`opa3$$ == 1, $CellContext`plot1$$ == 1], 
             Show[
              Plot[
               
               Cos[$CellContext`x 
                Degree], {$CellContext`x, -$CellContext`\[Beta], \
$CellContext`\[Beta]}, Axes -> {{True, False}, {True, False}}, 
               AxesOrigin -> {0, 0}, 
               Ticks -> {{-90, -45, 0, 45, 90}, {0, 0.5, 1}}, AxesLabel -> {
                 Row[{"\[Theta]", "\[Degree]"}], "N / P"}, 
               ImageSize -> {200, 110}, PlotStyle -> {$CellContext`color}, 
               Epilog -> {Red, 
                 PointSize[$CellContext`pts], 
                 Point[{{$CellContext`an$$, 
                    Cos[$CellContext`an$$ Degree]}}]}], 
              Plot[
               
               Cos[$CellContext`x 
                Degree], {$CellContext`x, -90, -$CellContext`\[Beta]}, 
               PlotStyle -> {$CellContext`color, Dashed}], 
              Plot[
               Cos[$CellContext`x 
                Degree], {$CellContext`x, $CellContext`\[Beta], 90}, 
               PlotStyle -> {$CellContext`color, Dashed}], 
              Graphics[{Red, 
                Opacity[$CellContext`num1$$], 
                Text[
                 Row[{"N = ", 
                   NumberForm[
                    N[$CellContext`f], 3]}], {
                 0.9 $CellContext`tx, $CellContext`ty}]}], 
              PlotRange -> {{-90, 90}, {0, 1}}]]}, {
            Graphics[{
              Opacity[
               Boole[$CellContext`opa2$$ == 1]], LightBlue, 
              
              Which[-ArcTan[$CellContext`l/$CellContext`h$$] <= $CellContext`\
\[Theta]$ <= ArcTan[$CellContext`l/$CellContext`h$$], 
               
               Polygon[{{0, 0}, {
                 0, $CellContext`h$$}, {$CellContext`l/2 - ($CellContext`h$$/
                   2) Tan[$CellContext`\[Theta]$], $CellContext`h$$}, \
{$CellContext`l/2 + ($CellContext`h$$/2) Tan[$CellContext`\[Theta]$], 
                  0}}], $CellContext`\[Theta]$ > 
               ArcTan[$CellContext`l/$CellContext`h$$], 
               
               Polygon[{{0, 0}, {
                 0, $CellContext`h$$/2 + ($CellContext`l/2)/
                   Tan[$CellContext`\[Theta]$]}, {$CellContext`l, \
$CellContext`h$$/2 - ($CellContext`l/2)/
                  Tan[$CellContext`\[Theta]$]}, {$CellContext`l, 
                  0}}], $CellContext`\[Theta]$ < -
                ArcTan[$CellContext`l/$CellContext`h$$], 
               
               Polygon[{{
                 0, $CellContext`h$$/2 + ($CellContext`l/2)/
                   Tan[$CellContext`\[Theta]$]}, {
                 0, $CellContext`h$$}, {$CellContext`l, $CellContext`h$$}, \
{$CellContext`l, $CellContext`h$$/2 - ($CellContext`l/2)/
                  Tan[$CellContext`\[Theta]$]}}]], Black, 
              Thickness[0.005], 
              
              Arrow[{{$CellContext`l/2, $CellContext`h$$/
                 2}, {$CellContext`l/2 + $CellContext`pw, $CellContext`h$$/
                 2}}], 
              
              Arrow[{{0, $CellContext`h$$/
                 2}, {-$CellContext`pw, $CellContext`h$$/2}}], Black, 
              Text["P", {(-$CellContext`pw)/2, $CellContext`h$$}], 
              Text[
              "P", {$CellContext`l/2 + $CellContext`pw/2, $CellContext`h$$}]},
              
             PlotRange -> {{$CellContext`rgxn, $CellContext`rgxp}, \
{$CellContext`rgyn, $CellContext`rgyp}}, ImageSize -> $CellContext`imz], 
            If[
             And[$CellContext`opa3$$ == 1, $CellContext`plot1$$ == 1], 
             Show[
              
              Plot[-Sin[$CellContext`x 
                 Degree], {$CellContext`x, -$CellContext`\[Beta], \
$CellContext`\[Beta]}, Axes -> {{True, False}, {True, False}}, 
               AxesOrigin -> {0, 0}, 
               Ticks -> {{-90, -45, 0, 45, 90}, {-1, 0, 1}}, AxesLabel -> {
                 Row[{"\[Theta]", "\[Degree]"}], "V / P"}, 
               ImageSize -> {200, 110}, PlotStyle -> {$CellContext`color}, 
               Epilog -> {Blue, 
                 PointSize[$CellContext`pts], 
                 Point[{{$CellContext`an$$, -Sin[$CellContext`an$$ Degree]}}], 
                 Opacity[$CellContext`num1$$]}], 
              
              Plot[-Sin[$CellContext`x 
                 Degree], {$CellContext`x, -90, -$CellContext`\[Beta]}, 
               PlotStyle -> {$CellContext`color, Dashed}], 
              
              Plot[-Sin[$CellContext`x 
                 Degree], {$CellContext`x, $CellContext`\[Beta], 90}, 
               PlotStyle -> {$CellContext`color, Dashed}], 
              Graphics[{Blue, 
                Opacity[$CellContext`num1$$], 
                Text[
                 Row[{"V = ", 
                   NumberForm[
                    N[-$CellContext`v], 3]}], {
                 0.9 $CellContext`tx, $CellContext`ty}]}], 
              PlotRange -> {{-90, 90}, {-1, 1}}]]}, {
            Graphics[{
              Opacity[
               Boole[$CellContext`opa3$$ == 1]], LightBlue, 
              
              Which[-ArcTan[$CellContext`l/$CellContext`h$$] <= $CellContext`\
\[Theta]$ <= ArcTan[$CellContext`l/$CellContext`h$$], 
               
               Polygon[{{0, 0}, {
                 0, $CellContext`h$$}, {$CellContext`l/2 - ($CellContext`h$$/
                   2) Tan[$CellContext`\[Theta]$], $CellContext`h$$}, \
{$CellContext`l/2 + ($CellContext`h$$/2) Tan[$CellContext`\[Theta]$], 
                  0}}], $CellContext`\[Theta]$ > 
               ArcTan[$CellContext`l/$CellContext`h$$], 
               
               Polygon[{{0, 0}, {
                 0, $CellContext`h$$/2 + ($CellContext`l/2)/
                   Tan[$CellContext`\[Theta]$]}, {$CellContext`l, \
$CellContext`h$$/2 - ($CellContext`l/2)/
                  Tan[$CellContext`\[Theta]$]}, {$CellContext`l, 
                  0}}], $CellContext`\[Theta]$ < -
                ArcTan[$CellContext`l/$CellContext`h$$], 
               
               Polygon[{{
                 0, $CellContext`h$$/2 + ($CellContext`l/2)/
                   Tan[$CellContext`\[Theta]$]}, {
                 0, $CellContext`h$$}, {$CellContext`l, $CellContext`h$$}, \
{$CellContext`l, $CellContext`h$$/2 - ($CellContext`l/2)/
                  Tan[$CellContext`\[Theta]$]}}]], Black, 
              Thickness[0.005], 
              
              Arrow[{{0, $CellContext`h$$/
                 2}, {-$CellContext`pw, $CellContext`h$$/2}}], 
              
              Arrow[{{$CellContext`l/2, $CellContext`h$$/
                 2}, {$CellContext`l/2 + $CellContext`pw, $CellContext`h$$/
                 2}}], 
              If[$CellContext`\[Theta]$ != Pi/2, {Red, 
                
                Arrow[{{$CellContext`l/2, $CellContext`h$$/
                   2}, {$CellContext`l/2 + $CellContext`fw 
                    Cos[$CellContext`\[Theta]$], $CellContext`h$$/
                    2 + $CellContext`fw Sin[$CellContext`\[Theta]$]}}]}], 
              If[$CellContext`\[Theta]$ != 0, {Blue, 
                
                Arrow[{{$CellContext`l/2, $CellContext`h$$/
                   2}, {$CellContext`l/2 + $CellContext`vw 
                    Sin[$CellContext`\[Theta]$], $CellContext`h$$/
                    2 - $CellContext`vw Cos[$CellContext`\[Theta]$]}}]}], 
              Black, 
              Text["P", {(-$CellContext`pw)/2, $CellContext`h$$}], Red, 
              Which[
               
               And[$CellContext`\[Theta]$ != 0, $CellContext`\[Theta]$ != 
                Pi/2, $CellContext`\[Theta]$ != (-Pi)/2], {Dashed, Black, 
                
                Line[{{$CellContext`l/2 + $CellContext`pw, $CellContext`h$$/
                   2}, {$CellContext`l/2 + $CellContext`fw 
                    Cos[$CellContext`\[Theta]$], $CellContext`h$$/
                    2 + $CellContext`fw Sin[$CellContext`\[Theta]$]}}], 
                
                Line[{{$CellContext`l/2 + $CellContext`pw, $CellContext`h$$/
                   2}, {$CellContext`l/2 + $CellContext`vw 
                    Sin[$CellContext`\[Theta]$], $CellContext`h$$/
                    2 - $CellContext`vw Cos[$CellContext`\[Theta]$]}}], Black, 
                Text[
                "P", {$CellContext`l/2 + 
                  1.5 $CellContext`pw, $CellContext`h$$/2}], Red, 
                Text[
                "N", {$CellContext`l/2 + (1.4 $CellContext`fw) 
                   Cos[$CellContext`\[Theta]$], $CellContext`h$$/
                   2 + (1.4 $CellContext`fw) Sin[$CellContext`\[Theta]$]}], 
                Blue, 
                Text[
                "V", {$CellContext`l/2 + (1.4 $CellContext`vw) 
                   Sin[$CellContext`\[Theta]$], $CellContext`h$$/2 - (
                   1.4 $CellContext`vw) 
                  Cos[$CellContext`\[Theta]$]}]}, $CellContext`\[Theta]$ == 
               0, {Red, 
                Text[
                "N = P", {$CellContext`l/2 + 
                  1.5 $CellContext`pw, $CellContext`h$$/2}]}, 
               
               Or[$CellContext`\[Theta]$ == 
                Pi/2, $CellContext`\[Theta]$ == (-Pi)/2], {Blue, 
                Text[
                "V = P", {$CellContext`l/2 + $CellContext`pw/
                   2, $CellContext`h$$}]}], Gray, 
              Arrowheads[0.02], 
              
              Arrow[{{0.25 $CellContext`l, 0.2 $CellContext`h$$}, {
                 0.25 $CellContext`l, 0.2 $CellContext`h$$} + (
                  0.5 $CellContext`h$$) {
                   Cos[$CellContext`\[Theta]$], 
                   Sin[$CellContext`\[Theta]$]}}], 
              
              Arrow[{{0.25 $CellContext`l, 0.2 $CellContext`h$$}, {
                 0.25 $CellContext`l, 0.2 $CellContext`h$$} + (
                  0.5 $CellContext`h$$) {
                   Cos[$CellContext`\[Theta]$ + Pi/2], 
                   Sin[$CellContext`\[Theta]$ + Pi/2]}}], 
              Text[
               Style[
               "n", 8], {
                0.25 $CellContext`l, 0.2 $CellContext`h$$} + (
                 0.6 $CellContext`h$$) {
                  Cos[$CellContext`\[Theta]$], 
                  Sin[$CellContext`\[Theta]$]}], 
              Text[
               Style[
               "t", 8], {
                0.25 $CellContext`l, 0.2 $CellContext`h$$} + (
                 0.6 $CellContext`h$$) {
                  Cos[$CellContext`\[Theta]$ + Pi/2], 
                  Sin[$CellContext`\[Theta]$ + Pi/2]}]}, 
             PlotRange -> {{$CellContext`rgxn, $CellContext`rgxp}, \
{$CellContext`rgyn, $CellContext`rgyp}}, ImageSize -> $CellContext`imz], 
            If[
             And[$CellContext`opa4$$ == 1, $CellContext`plot2$$ == 1], 
             Show[
              Plot[
              Cos[$CellContext`x 
                 Degree]^2, {$CellContext`x, -$CellContext`\[Beta], \
$CellContext`\[Beta]}, Axes -> {{True, False}, {True, False}}, 
               AxesOrigin -> {0, 0}, 
               Ticks -> {{-90, -45, 0, 45, 90}, {0, 0.5, 1}}, AxesLabel -> {
                 Row[{"\[Theta]", "\[Degree]"}], 
                 Row[{"\[Sigma]", " / ", 
                   Subscript["\[Sigma]", "0"]}]}, ImageSize -> {220, 110}, 
               PlotStyle -> {$CellContext`color}, Epilog -> {Red, 
                 PointSize[$CellContext`pts], 
                 
                 Point[{{$CellContext`an$$, 
                    Cos[$CellContext`an$$ Degree]^2}}]}], 
              Plot[
              Cos[$CellContext`x 
                 Degree]^2, {$CellContext`x, -90, -$CellContext`\[Beta]}, 
               PlotStyle -> {$CellContext`color, Dashed}], 
              Plot[
              Cos[$CellContext`x 
                 Degree]^2, {$CellContext`x, $CellContext`\[Beta], 90}, 
               PlotStyle -> {$CellContext`color, Dashed}], 
              Graphics[{Red, 
                Opacity[$CellContext`num2$$], 
                Text[
                 Column[{
                   Row[{"\[Sigma] = ", 
                    NumberForm[
                    N[$CellContext`ns], 3]}], 
                   Row[{
                    Subscript["\[Sigma]", "0"], " = ", 
                    NumberForm[
                    N[$CellContext`p$$/$CellContext`area], 3]}]}, Right], {
                 0.87 $CellContext`tx, 0.8 $CellContext`ty}]}], 
              PlotRange -> {{-90, 90}, {0, 1}}]]}, {
            Graphics[{
              Opacity[
               Boole[$CellContext`opa4$$ == 1]], Black, 
              Thickness[0.005], 
              
              Arrow[{{0, $CellContext`h$$/
                 2}, {-$CellContext`pw, $CellContext`h$$/2}}], Black, 
              Text["P", {(-$CellContext`pw)/2, $CellContext`h$$}], 
              
              Which[-ArcTan[$CellContext`l/$CellContext`h$$] <= $CellContext`\
\[Theta]$ <= ArcTan[$CellContext`l/$CellContext`h$$], {LightBlue, 
                
                Polygon[{{0, 0}, {
                  0, $CellContext`h$$}, {$CellContext`l/2 - ($CellContext`h$$/
                    2) Tan[$CellContext`\[Theta]$], $CellContext`h$$}, \
{$CellContext`l/2 + ($CellContext`h$$/2) Tan[$CellContext`\[Theta]$], 0}}], 
                Red, 
                Thickness[0.005], 
                Arrowheads[0.02], 
                Translate[{
                  Map[
                  Arrow[{{$CellContext`l/2 - ($CellContext`h$$/2) 
                    Tan[$CellContext`\[Theta]$], $CellContext`h$$} + # {
                    Tan[$CellContext`\[Theta]$], -1}, {$CellContext`l/
                    2 - ($CellContext`h$$/2) 
                    Tan[$CellContext`\[Theta]$] + $CellContext`nsw 
                    Cos[$CellContext`\[Theta]$], $CellContext`h$$ + \
$CellContext`nsw Sin[$CellContext`\[Theta]$]} + # {
                    Tan[$CellContext`\[Theta]$], -1}}]& , $CellContext`nq], 
                  Text[
                  "\[Sigma]", {$CellContext`l/2, $CellContext`h$$/2} + (
                    1.25 $CellContext`nsw) {
                    Cos[$CellContext`\[Theta]$], 
                    Sin[$CellContext`\[Theta]$]}]}, (0.2 $CellContext`h$$) {
                   Cos[$CellContext`\[Theta]$], 
                   Sin[$CellContext`\[Theta]$]}], 
                If[$CellContext`\[Theta]$ != 0, {Blue, 
                  Translate[{
                    Map[
                    Arrow[{{$CellContext`l/2 - ($CellContext`h$$/2) 
                    Tan[$CellContext`\[Theta]$], $CellContext`h$$} + # {
                    Tan[$CellContext`\[Theta]$], -1}, {$CellContext`l/
                    2 - ($CellContext`h$$/2) 
                    Tan[$CellContext`\[Theta]$] + $CellContext`ssw 
                    Sin[$CellContext`\[Theta]$], $CellContext`h$$ - \
$CellContext`ssw Cos[$CellContext`\[Theta]$]} + # {
                    Tan[$CellContext`\[Theta]$], -1}}]& , $CellContext`sq], 
                    Text[
                    "\[Tau]", {$CellContext`l/2, $CellContext`h$$/2} - (0.2 
                    Abs[$CellContext`ssw]) {
                    Cos[$CellContext`\[Theta]$], 
                    Sin[$CellContext`\[Theta]$]}]}, (0.1 $CellContext`h$$) {
                    Cos[$CellContext`\[Theta]$], 
                    Sin[$CellContext`\[Theta]$]}]}]}, $CellContext`\[Theta]$ > 
               ArcTan[$CellContext`l/$CellContext`h$$], {LightBlue, 
                
                Polygon[{{0, 0}, {
                  0, $CellContext`h$$/2 + ($CellContext`l/2)/
                    Tan[$CellContext`\[Theta]$]}, {$CellContext`l, \
$CellContext`h$$/2 - ($CellContext`l/2)/
                   Tan[$CellContext`\[Theta]$]}, {$CellContext`l, 0}}], 
                If[$CellContext`\[Theta]$ != Pi/2, {Red, 
                  Thickness[0.005], 
                  Arrowheads[0.02], 
                  Translate[{
                    Map[
                    Arrow[{{
                    0, $CellContext`h$$/2 + ($CellContext`l/2)/
                    Tan[$CellContext`\[Theta]$]} + # {
                    1, (-1)/Tan[$CellContext`\[Theta]$]}, {$CellContext`nsw 
                    Cos[$CellContext`\[Theta]$], $CellContext`h$$/
                    2 + ($CellContext`l/2)/
                    Tan[$CellContext`\[Theta]$] + $CellContext`nsw 
                    Sin[$CellContext`\[Theta]$]} + # {
                    1, (-1)/
                    Tan[$CellContext`\[Theta]$]}}]& , $CellContext`nq2], 
                    Text[
                    "\[Sigma]", {$CellContext`l/2, $CellContext`h$$/2} + (
                    1.25 $CellContext`nsw) {
                    Cos[$CellContext`\[Theta]$], 
                    Sin[$CellContext`\[Theta]$]}]}, (0.2 $CellContext`h$$) {
                    Cos[$CellContext`\[Theta]$], 
                    Sin[$CellContext`\[Theta]$]}], Blue, 
                  Translate[{
                    Map[
                    Arrow[{{
                    0, $CellContext`h$$/2 + ($CellContext`l/2)/
                    Tan[$CellContext`\[Theta]$]} + # {
                    1, (-1)/Tan[$CellContext`\[Theta]$]}, {
                    Abs[$CellContext`ssw] 
                    Sin[$CellContext`\[Theta]$], $CellContext`h$$/
                    2 + ($CellContext`l/2)/Tan[$CellContext`\[Theta]$] - 
                    Abs[$CellContext`ssw] Cos[$CellContext`\[Theta]$]} + # {
                    1, (-1)/
                    Tan[$CellContext`\[Theta]$]}}]& , $CellContext`sq2], 
                    Text[
                    "\[Tau]", {$CellContext`l/2, $CellContext`h$$/2} - (0.2 
                    Abs[$CellContext`ssw]) {
                    Cos[$CellContext`\[Theta]$], 
                    Sin[$CellContext`\[Theta]$]}]}, (0.1 $CellContext`h$$) {
                    Cos[$CellContext`\[Theta]$], 
                    
                    Sin[$CellContext`\[Theta]$]}]}]}, $CellContext`\[Theta]$ < \
-ArcTan[$CellContext`l/$CellContext`h$$], {LightBlue, 
                
                Polygon[{{
                  0, $CellContext`h$$/2 + ($CellContext`l/2)/
                    Tan[$CellContext`\[Theta]$]}, {
                  0, $CellContext`h$$}, {$CellContext`l, $CellContext`h$$}, \
{$CellContext`l, $CellContext`h$$/2 - ($CellContext`l/2)/
                   Tan[$CellContext`\[Theta]$]}}], 
                If[$CellContext`\[Theta]$ != (-Pi)/2, {Red, 
                  Thickness[0.005], 
                  Arrowheads[0.02], 
                  Translate[{
                    Map[
                    Arrow[{{
                    0, $CellContext`h$$/2 + ($CellContext`l/2)/
                    Tan[$CellContext`\[Theta]$]} + # {
                    1, (-1)/Tan[$CellContext`\[Theta]$]}, {$CellContext`nsw 
                    Cos[$CellContext`\[Theta]$], $CellContext`h$$/
                    2 + ($CellContext`l/2)/
                    Tan[$CellContext`\[Theta]$] + $CellContext`nsw 
                    Sin[$CellContext`\[Theta]$]} + # {
                    1, (-1)/
                    Tan[$CellContext`\[Theta]$]}}]& , $CellContext`nq2], 
                    Text[
                    "\[Sigma]", {$CellContext`l/2, $CellContext`h$$/2} + (
                    1.25 $CellContext`nsw) {
                    Cos[$CellContext`\[Theta]$], 
                    Sin[$CellContext`\[Theta]$]}]}, (0.2 $CellContext`h$$) {
                    Cos[$CellContext`\[Theta]$], 
                    Sin[$CellContext`\[Theta]$]}], Blue, 
                  Translate[{
                    Map[
                    Arrow[{{
                    0, $CellContext`h$$/2 + ($CellContext`l/2)/
                    Tan[$CellContext`\[Theta]$]} + # {
                    1, (-1)/Tan[$CellContext`\[Theta]$]}, {
                    Abs[$CellContext`ssw] 
                    Sin[$CellContext`\[Theta]$], $CellContext`h$$/
                    2 + ($CellContext`l/2)/Tan[$CellContext`\[Theta]$] - 
                    Abs[$CellContext`ssw] Cos[$CellContext`\[Theta]$]} + # {
                    1, (-1)/
                    Tan[$CellContext`\[Theta]$]}}]& , $CellContext`sq2], 
                    Text[
                    "\[Tau]", {$CellContext`l/2, $CellContext`h$$/2} - (0.2 
                    Abs[$CellContext`ssw]) {
                    Cos[$CellContext`\[Theta]$], 
                    Sin[$CellContext`\[Theta]$]}]}, (0.1 $CellContext`h$$) {
                    Cos[$CellContext`\[Theta]$], 
                    Sin[$CellContext`\[Theta]$]}]}]}]}, 
             PlotRange -> {{$CellContext`rgxn, $CellContext`rgxp}, \
{$CellContext`rgyn, $CellContext`rgyp}}, ImageSize -> $CellContext`imz], 
            If[
             And[$CellContext`opa4$$ == 1, $CellContext`plot2$$ == 1], 
             Show[
              
              Plot[(-Sin[$CellContext`x Degree]) 
               Cos[$CellContext`x 
                 Degree], {$CellContext`x, -$CellContext`\[Beta], \
$CellContext`\[Beta]}, Axes -> {{True, False}, {True, False}}, 
               AxesOrigin -> {0, 0}, 
               Ticks -> {{-90, -45, 0, 45, 90}, {-0.5, 0, 0.5}}, AxesLabel -> {
                 Row[{"\[Theta]", "\[Degree]"}], 
                 Row[{"\[Tau]", " / ", 
                   Subscript["\[Sigma]", "0"]}]}, ImageSize -> {210, 110}, 
               PlotStyle -> {$CellContext`color}, Epilog -> {Blue, 
                 PointSize[$CellContext`pts], 
                 
                 Point[{{$CellContext`an$$, (-Sin[$CellContext`an$$ Degree]) 
                    Cos[$CellContext`an$$ Degree]}}]}], 
              
              Plot[(-Sin[$CellContext`x Degree]) 
               Cos[$CellContext`x 
                 Degree], {$CellContext`x, -90, -$CellContext`\[Beta]}, 
               PlotStyle -> {$CellContext`color, Dashed}], 
              
              Plot[(-Sin[$CellContext`x Degree]) 
               Cos[$CellContext`x 
                 Degree], {$CellContext`x, $CellContext`\[Beta], 90}, 
               PlotStyle -> {$CellContext`color, Dashed}], 
              Graphics[{Blue, 
                Opacity[$CellContext`num2$$], 
                Text[
                 Column[{
                   Row[{"\[Tau] = ", 
                    NumberForm[
                    N[-$CellContext`ss], 3]}], 
                   Row[{
                    Subscript["\[Sigma]", "0"], " = ", 
                    NumberForm[
                    N[$CellContext`p$$/$CellContext`area], 3]}]}, Right], {
                 0.8 $CellContext`tx, 0.4 $CellContext`ty}]}], 
              PlotRange -> {{-90, 90}, {-0.5, 0.5}}]]}}]], 
      "Specifications" :> {{{$CellContext`p$$, 5, ""}, -10, 10, 0.1, 
         Appearance -> "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         1}, {{$CellContext`an$$, 45, ""}, -75, 75, 0.1, Appearance -> 
         "Labeled", ImageSize -> Tiny, ControlPlacement -> 
         2}, {{$CellContext`h$$, 2, ""}, 1, 2.5, 0.1, Appearance -> "Labeled",
          ImageSize -> Tiny, ControlPlacement -> 3}, {{$CellContext`opa2$$, 0, 
          Row[{
            Text[
             Style["Equilibrium", Bold]], 
            Spacer[28]}]}, {1 -> "On", 0 -> "Off"}, ControlType -> SetterBar, 
         ControlPlacement -> 4}, {{$CellContext`opa3$$, 0, 
          Row[{
            Text[
             Style["Resolution", Bold]], 
            Spacer[30]}]}, {1 -> "On", 0 -> "Off"}, ControlType -> SetterBar, 
         ControlPlacement -> 5}, {{$CellContext`plot1$$, 0, 
          Row[{
            Text[
             Style["Forces plot", Bold]], 
            Spacer[27]}]}, {1 -> "On", 0 -> "Off"}, ControlType -> SetterBar, 
         ControlPlacement -> 6}, {{$CellContext`num1$$, 0, 
          Row[{
            Text[
             Style["Numeric Value", Bold]], 
            Spacer[11]}]}, {1 -> "On", 0 -> "Off"}, ControlType -> SetterBar, 
         ControlPlacement -> 7}, {{$CellContext`opa4$$, 0, 
          Text[
           Style["Internal stresses", Bold]]}, {1 -> "On", 0 -> "Off"}, 
         ControlType -> SetterBar, ControlPlacement -> 
         8}, {{$CellContext`plot2$$, 0, 
          Row[{
            Text[
             Style["Stresses plot", Bold]], 
            Spacer[18]}]}, {1 -> "On", 0 -> "Off"}, ControlType -> SetterBar, 
         ControlPlacement -> 9}, {{$CellContext`num2$$, 0, 
          Row[{
            Text[
             Style["Numeric Value", Bold]], 
            Spacer[11]}]}, {1 -> "On", 0 -> "Off"}, ControlType -> SetterBar, 
         ControlPlacement -> 10}, 
        Grid[{{
           Grid[{{
              Text[
               Style["Parameters Setting", Bold]], SpanFromLeft}, {"P", 
              Manipulate`Place[1]}, {"\[Theta]", 
              Manipulate`Place[2]}, {"H", 
              Manipulate`Place[3]}, {
              Text[
               Style["Unit Width, W = 1"]], SpanFromLeft}}, 
            Spacings -> {0, 1}, Alignment -> Left, Frame -> None]}, {
           Grid[{{
              Manipulate`Place[4]}}, Alignment -> Left, Frame -> None]}, {
           Grid[{{
              Manipulate`Place[5]}, {
              PaneSelector[{1 -> Manipulate`Place[6]}, 
               Dynamic[
                Boole[$CellContext`opa3$$ == 1]]]}, {
              PaneSelector[{1 -> Manipulate`Place[7]}, 
               Dynamic[
                Boole[
                 
                 And[$CellContext`opa3$$ == 1, $CellContext`plot1$$ == 
                  1]]]]}}, Alignment -> Left, Frame -> None]}, {
           Grid[{{
              Manipulate`Place[8]}, {
              PaneSelector[{1 -> Manipulate`Place[9]}, 
               Dynamic[
                Boole[$CellContext`opa4$$ == 1]]]}, {
              PaneSelector[{1 -> Manipulate`Place[10]}, 
               Dynamic[
                Boole[
                 
                 And[$CellContext`opa4$$ == 1, $CellContext`plot2$$ == 
                  1]]]]}}, Alignment -> Left, Frame -> None]}}, 
         Spacings -> {0, {1, 3.7, 6.5, 3.5}}, Alignment -> Left]}, 
      "Options" :> {ControlPlacement -> Left, Alignment -> Left}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{763., {377., 386.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 TextAlignment->Center]
}, Open  ]]
},
WindowSize->{1366, 685},
Visible->True,
ScrollingOptions->{"VerticalScrollRange"->Fit},
ShowCellBracket->Automatic,
CellContext->Notebook,
TrackCellChangeTimes->False,
Magnification:>1.5 Inherited,
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (July 28, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[1486, 35, 209, 7, 230, "Title"],
Cell[1698, 44, 1575, 34, 342, "Text"],
Cell[3276, 80, 35723, 742, 787, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

(* NotebookSignature ExDBtykSIiUMVDgNVNa@kLG8 *)
